<?php

/**
 * Protects server from uploading files like file.php.mp3. Should be moved into core.
 */
function _file_munge_filename($filename, $extensions, $alerts = 1) {
  $original = $filename;
  $whitelist = array_unique(explode(' ', trim($extensions)));

  $filename_parts = explode('.', $filename);

  $new_filename = array_shift($filename_parts); // Remove file basename.
  $final_extension = array_pop($filename_parts); // Remove final extension.

  foreach($filename_parts as $filename_part) {
    $new_filename .= ".$filename_part";
    if (!in_array($filename_part, $whitelist) && preg_match("/^[a-zA-Z]{2,5}\d?$/", $filename_part)) {
      $new_filename .= '_';
    }
  }
  $filename = "$new_filename.$final_extension";

  if ($alerts && $original != $filename) {
    $message = t('Your filename has been renamed to conform to site policy.');
    drupal_set_message($message, 'warning');
  }

  return $filename;
}

/**
 * insert a video file into the database.
 * @param $node
 *    node object file will be associated with.
 * @param $file
 *    file to be inserted, passed by reference since fid should be attached.
 *
 */
function _field_file_insert($node, &$file, $field) {
  $fieldname = $field['field_name'];
  $safe_filename = _file_munge_filename($file['filename'], trim($field['widget']['file_extensions']));
  if ($file = file_save_upload((object)$file, file_directory_path() . '/'.$field['widget']['save_path'].'/'. $safe_filename)) {
    $file = (array)$file;
    $file['fid'] = db_next_id('{files}_fid');
    db_query('INSERT into {files} (fid, nid, filename, filepath, filemime, filesize)
             VALUES (%d, %d, "%s","%s","%s",%d)',
            $file['fid'], $node->nid, $file['filename'], $file['filepath'], $file['filemime'], $file['filesize']);
    return (array)$file;
  }
  else {
    form_set_error(NULL, t('file upload was unsuccessful.'));
    return FALSE;
  }
}

/**
 * update the video file record if necessary
 * @param $node
 * @param $file
 * @param $field
 */
function _field_file_update($node, &$file, $field) {
  $file = (array)$file;
  if ($file['remove'] == TRUE) {
     _field_file_delete($file, $field['field_name'], $field['type']);
     return NULL;
  }
  if ($file['fid'] == 'upload') {
    return _field_file_insert($node, $file, $field);
  }
  else {
  }
  return $file;
}

/**
 * Enter description here...
 *
 * @param unknown_type $file
 * @param unknown_type $fieldname
 * @return unknown
 */
function _field_file_delete($file, $fieldname, $type) {
  if (is_numeric($file['fid'])) {
    db_query('DELETE FROM {files} WHERE fid = %d', $file['fid']);
  }
  else {
    unset($_SESSION[$type][$fieldname][$file['sessionid']]);
  }
  return file_delete($file['filepath']);
}


/**
 * Enter description here...
 *
 */
function _field_clear_session($type) {
  if (is_array($_SESSION[$type]) && count($_SESSION[$type])) {
    foreach (array_keys($_SESSION[$type]) as $fieldname) {
      _field_clear_field_session($fieldname, $type);
    }
    unset($_SESSION[$type]);
  }
}

/**
 * Enter description here...
 *
 * @param unknown_type $fieldname
 */
function _field_clear_field_session($fieldname, $type) {
  if (count($_SESSION[$type][$fieldname])) {
    foreach ($_SESSION[$type][$fieldname] as $files) {
      foreach ($files as $delta => $file) {
        if (is_file($file['filepath'])) {
          file_delete($file['filepath']);
        }
      }
    }
    unset($_SESSION[$type][$fieldname]);
  }
}

function _field_file_load($fid = NULL) {
  if (isset($fid)) {
    if (is_numeric($fid)) {
      $result = db_query('SELECT * FROM {files} WHERE fid = %d', $fid);
      $file = db_fetch_array($result);
      return ($file) ? $file : array();
    }
  }
  return array();
}

/**
 * Enter description here...
 */
function &getID3Instance() {
  $lib = 'misc/lib/getid3/getid3/getid3.php';
  $id3 = null;

  if (file_exists($lib)) {
    require_once($lib);
    $id3 = new getID3();
    $id3-> option_md5_data = true;
    $id3-> option_md5_data_source = true;
    $id3-> encoding = 'UTF-8';
 }
 else {
  drupal_set_message('getid3 library not found!!!!', 'error');
 }

 return $id3;
}

/**
 * Enter description here...
 */
function &getID3Analyze($path) {
  $info = array();
  if($id3 = &getID3Instance()) {
    $info = $id3-> analyze($path);
    unset($id3);
  }

  return $info;
}

/**
 * Enter description here...
 */
function format_samplerate($samplerate) {
  return sprintf("%.1f kHz", $samplerate/1000);
}

/**
 * Enter description here...
 */
function format_bitrate($bitrate) {
  return sprintf("%d Kbps", $bitrate/1000);
}

/**
 * Enter description here...
 */
function format_filesize($size) {
  $size = $size/1000;
  $result = '';
  if ($size > 0) {
    $result = sprintf("%.02f MB", $size/1000);
  }else {
    $result = sprintf("%.02f Kb", $size);
  }
  return $result;
}

?>